==> deepin-camera_6.5.20.tar.xz: BUILD/src/translations/deepin-camera_id.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="id">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Perekaman video sedang berlangsung. Tutup jendela?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Buka folder</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Pengaturan</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Kosong</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Foto</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Ganti Kamera</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Tutup</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Hapus</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Buka folder</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Cetak</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Anda tidak memiliki izin untuk mengoperasikan folder ini</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Tutup</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Folder tidak valid</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Buka folder</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Pengaturan</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Dasar</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Lokasi file</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Mode burst</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Output</source>
        <translation>Keluaran</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Format keluaran</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 pcs</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 pcs</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Kosong</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kamera adalah utilitas pengambil gambar dan video menggunakan kamera PC atau webcam Anda</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>File tidak disimpan</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Simpan ke:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Foto:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Pengaturan resolusi</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Resolusi:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Foto:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Efek suara</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Mode mirror </translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Senter</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Pengaturan</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Berhenti merekam</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Hapus</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Buka</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Cetak</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Bantuan</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Tampilkan pintasan</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Berhenti mengambil foto</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Menu konteks</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Ambil foto</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Rekam video</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Berhenti mengambil foto</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Kosong</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Vivid</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Warm</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Cold</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Film</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Gray</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>B&amp;W</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Senter</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Nyalakan</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Padamkan</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>None</source>
        <translation>Kosong</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Webcam tidak ditemukan</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Webcam sedang digunakan</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Berhenti merekam</translation>
    </message>
</context>
</TS>

==> deepin-camera_6.5.23.tar.xz: BUILD/src/translations/deepin-camera_id.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="id">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Perekaman video sedang berlangsung. Tutup jendela?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Buka folder</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Pengaturan</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Kosong</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Foto</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Ganti Kamera</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Tutup</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Hapus</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Buka folder</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Cetak</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Anda tidak memiliki izin untuk mengoperasikan folder ini</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Tutup</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Folder tidak valid</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Buka folder</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Pengaturan</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Dasar</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Lokasi file</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Ambil</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Mode burst</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Waktu penundaan self-timer</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Keluaran</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Format keluaran</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 pcs</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 pcs</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Kosong</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kamera adalah utilitas pengambil gambar dan video menggunakan kamera PC atau webcam Anda</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>File tidak disimpan</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Simpan ke:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Foto:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Pengaturan resolusi</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Resolusi:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Foto:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Efek suara</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Mode mirror </translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Senter</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>Garis grid</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>1*1 garis</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>2*2 garis</translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation>Resolusi maksimum:</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Pengaturan</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Berhenti merekam</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Hapus</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Buka</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Cetak</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Bantuan</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Tampilkan pintasan</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Berhenti mengambil foto</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Menu konteks</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Ambil foto</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Rekam video</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Berhenti mengambil foto</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Kosong</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Vivid</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Warm</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Cold</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Film</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Gray</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>B&amp;W</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Senter</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Nyalakan</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Padamkan</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Tunda pengambilan</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Kosong</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Pengaturan eksposur</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Webcam tidak ditemukan</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Webcam sedang digunakan</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Berhenti merekam</translation>
    </message>
</context>
</TS>
